@@ -4,7 +4,7 @@
 
 #define QT_FEATURE_pipewire_screencapture -1
 
-#define QT_FEATURE_alsa 1
+#define QT_FEATURE_alsa -1
 
 #define QT_FEATURE_avfoundation -1
 
@@ -18,7 +18,7 @@
 
 #define QT_FEATURE_gstreamer_gl 1
 
-#define QT_FEATURE_gstreamer_gl_wayland 1
+#define QT_FEATURE_gstreamer_gl_wayland -1
 
 #define QT_FEATURE_gstreamer_gl_egl 1
 
@@ -36,7 +36,7 @@
 
 #define QT_FEATURE_native_android_backend -1
 
-#define QT_FEATURE_pulseaudio -1
+#define QT_FEATURE_pulseaudio 1
 
 #define QT_FEATURE_opensles -1
 
